@@ -4,7 +4,9 @@
 QCoreApplication *
 createAppObject(int &argc, char **argv)
 {
-    return SailfishApp::application (argc, argv);
+    QGuiApplication *app = SailfishApp::application (argc, argv);
+    app->setQuitOnLastWindowClosed(false);
+    return app;
 }//createAppObject
 
 MainWindow::MainWindow(QObject *parent)
@@ -28,6 +30,8 @@ MainWindow::initDerivedQmlObjects()
 void
 MainWindow::setNumberInDisp(const QString &number)
 {
+    QObject *dialPage = getQMLObject ("DialPage");
+
     QMetaObject::invokeMethod(dialPage, "setNumberInDisp",
                               Q_ARG(QVariant, QVariant(number)));
     int iTab = 0;
